@@ -1,3 +1,4 @@
+import os
 import kabuki
 import numpy as np
 import unittest
@@ -5,7 +6,6 @@ from nose.tools import raises
 import pymc as pm
 from utils import HNodeSimple, HNodeSimpleVar, sample_from_models, create_test_models
 import pandas as pd
-from pandas import Series, DataFrame
 
 class TestHierarchicalBreakDown(unittest.TestCase):
     """
@@ -26,6 +26,7 @@ class TestHierarchicalBreakDown(unittest.TestCase):
         pass
 
     def test_map(self):
+        np.random.seed(123)
         for model in self.models:
             if model.is_group_model:
                 model.approximate_map()
@@ -43,9 +44,14 @@ class TestHierarchicalBreakDown(unittest.TestCase):
             if model.is_group_model:
                 model.print_stats(subj_idx=1)
 
-    @unittest.skip("Not implemented")
-    def load_db(self):
-        pass
+    def test_load_db(self):
+        new_models, params = create_test_models()
+        for i, model in enumerate(new_models):
+            print "sample model", i
+            model.sample(100, dbname='unittest.db', db='pickle')
+            model.load_db(dbname='unittest.db', db='pickle')
+            model.gen_stats()
+            os.remove('unittest.db')
 
     @unittest.skip("TODO")
     def test_init_from_existing_model(self):
@@ -79,6 +85,14 @@ class TestModelCreation(unittest.TestCase):
     def runTest(self):
         pass
 
+    def test_save_and_load_breakdown(self):
+        m = HNodeSimple(self.data)
+        m.sample(500, dbname='test.db', db='pickle')
+        m.save('test.model')
+        m_load = kabuki.utils.load('test.model')
+        os.remove('test.db')
+        os.remove('test.model')
+
     def test_simple_no_deps(self):
         m = HNodeSimple(self.data)
         n_nodes = 1 + self.n_subj*2 #mu_g + n_subj * (mu_subj + like)
@@ -93,7 +107,7 @@ class TestModelCreation(unittest.TestCase):
     def test_assertion_on_wrong_param_name(self):
         HNodeSimple(self.data, depends_on={'non_existant': 'condition'})
 
-    def test_assertion_on_wrong_param_name(self):
+    def test_assertion_on_wrong_param_name_tofix(self):
         # does not catch if correct argument
         HNodeSimple(self.data, depends_on={'non_existant': 'condition', 'mu': 'condition'})
 
